@@ -1,6 +1,6 @@
 package CHI::Driver;
-BEGIN {
-  $CHI::Driver::VERSION = '0.56';
+{
+  $CHI::Driver::VERSION = '0.57';
 }
 use Carp;
 use CHI::CacheObject;
@@ -12,14 +12,14 @@ use CHI::Driver::Role::IsSubcache;
 use CHI::Driver::Role::Universal;
 use CHI::Serializer::Storable;
 use CHI::Serializer::JSON;
-use CHI::Util qw(has_moose_class parse_duration);
-use CHI::Types;
+use CHI::Util qw(parse_duration);
+use CHI::Types qw(:all);
 use Digest::MD5;
 use Encode;
 use Hash::MoreUtils qw(slice_grep);
 use Log::Any qw($log);
-use Moose;
-use Moose::Util::TypeConstraints;
+use Moo;
+use MooX::Types::MooseLike::Base qw(:all);
 use Scalar::Util qw(blessed);
 use Time::Duration;
 use Time::HiRes qw(gettimeofday);
@@ -30,43 +30,143 @@ my $default_serializer     = CHI::Serializer::Storable->new();
 my $default_key_serializer = CHI::Serializer::JSON->new();
 my $default_key_digester   = Digest::MD5->new();
 
-has 'chi_root_class'     => ( is => 'ro' );
-has 'compress_threshold' => ( is => 'ro', isa => 'Int' );
-has 'constructor_params' => ( is => 'ro', init_arg => undef );
-has 'driver_class'       => ( is => 'ro' );
-has 'expires_at'         => ( is => 'rw', default => CHI_Max_Time );
-has 'expires_in'         => ( is => 'rw', isa => 'CHI::Types::Duration', coerce => 1 );
-has 'expires_on_backend' => ( is => 'ro', isa => 'Num', default => 0 );
-has 'expires_variance'   => ( is => 'rw', isa => 'Num', default => 0 );
-has 'has_subcaches'      => ( is => 'ro', isa => 'Bool', default => undef, init_arg => undef );
-has 'is_size_aware'      => ( is => 'ro', isa => 'Bool', default => undef );
-has 'is_subcache'        => ( is => 'ro', isa => 'Bool', default => undef );
-has 'key_digester'       => ( is => 'ro', isa => 'CHI::Types::Digester', coerce => 1, default => sub { $default_key_digester } );
-has 'key_serializer'     => ( is => 'ro', isa => 'CHI::Types::Serializer', coerce => 1, default => sub { $default_key_serializer } );
-has 'label'              => ( is => 'rw', lazy_build => 1 );
-has 'max_build_depth'    => ( is => 'ro', default => 8 );
-has 'max_key_length'     => ( is => 'ro', isa => 'Int', default => 1 << 31 );
-has 'metacache'          => ( is => 'ro', lazy_build => 1 );
-has 'namespace'          => ( is => 'ro', isa => 'Str', default => 'Default' );
-has 'on_get_error'       => ( is => 'rw', isa => 'CHI::Types::OnError', default => 'log' );
-has 'on_set_error'       => ( is => 'rw', isa => 'CHI::Types::OnError', default => 'log' );
-has 'serializer'         => ( is => 'ro', isa => 'CHI::Types::Serializer', coerce => 1, default => sub { $default_serializer } );
-has 'short_driver_name'  => ( is => 'ro', lazy_build => 1 );
-has 'storage'            => ( is => 'ro' );
+my @common_params;
+{
+    my %attr = (
+        chi_root_class => {
+            is => 'ro',
+        },
+        compress_threshold => {
+            is => 'ro',
+            isa => Int,
+        },
+        constructor_params => {
+            is => 'ro',
+            init_arg => undef,
+        },
+        driver_class => {
+            is => 'ro',
+        },
+        expires_at => {
+            is => 'rw',
+            default => sub { CHI_Max_Time },
+        },
+        expires_in => { is => 'rw',
+            isa => Duration,
+            coerce => \&to_Duration,
+        },
+        expires_on_backend => {
+            is => 'ro',
+            isa => Num,
+            default => sub { 0 },
+        },
+        expires_variance => {
+            is => 'rw',
+            isa => Num,
+            default => sub { 0 },
+        },
+        has_subcaches => {
+            is => 'lazy',
+            isa => Bool,
+            init_arg => undef,
+        },
+        is_size_aware => {
+            is => 'ro',
+            isa => Bool,
+        },
+        is_subcache => {
+            is => 'ro',
+            isa => Bool,
+        },
+        key_digester => {
+            is => 'ro',
+            isa => Digester,
+            coerce => \&to_Digester,
+            default => sub { $default_key_digester },
+        },
+        key_serializer => {
+            is => 'ro',
+            isa => Serializer,
+            coerce => \&to_Serializer,
+            default => sub { $default_key_serializer },
+        },
+        label => {
+            is => 'rw',
+            lazy => 1,
+            builder => 1,
+            clearer => 1,
+            predicate => 1,
+        },
+        max_build_depth => {
+            is => 'ro',
+            default => sub { 8 },
+        },
+        max_key_length => {
+            is => 'ro',
+            isa => Int,
+            default => sub { 1 << 31 },
+        },
+        metacache => {
+            is => 'lazy',
+            clearer => 1,
+            predicate => 1,
+        },
+        namespace => {
+            is => 'ro',
+            isa => Str,
+            default => sub { 'Default' },
+        },
+        on_get_error => {
+            is => 'rw',
+            isa => OnError,
+            default => sub { 'log' },
+        },
+        on_set_error => {
+            is => 'rw',
+            isa => OnError,
+            default => sub { 'log' },
+        },
+        serializer => {
+            is => 'ro',
+            isa => Serializer,
+            coerce => \&to_Serializer,
+            default => sub { $default_serializer },
+        },
+        short_driver_name => {
+            is => 'lazy',
+            clearer => 1,
+            predicate => 1,
+        },
+        storage => {
+            is => 'ro',
+        },
+    );
+    push @common_params, keys %attr;
+    for my $attr ( keys %attr ) {
+        has $attr => %{$attr{$attr}};
+    }
+}
+
+sub _build_has_subcaches { undef }
 
 # These methods must be implemented by subclass
 foreach my $method (qw(fetch store remove get_keys get_namespaces)) {
-    __PACKAGE__->meta->add_method( $method =>
-          sub { die "method '$method' must be implemented by subclass" } );
+    no strict 'refs';
+    *{$method} = sub { die "method '$method' must be implemented by subclass" };
 }
 
-__PACKAGE__->meta->make_immutable();
-
 # Given a hash of params, return the subset that are not in CHI's common parameters.
 #
-my @common_params = map { $_->meta->get_attribute_list() } (
-    'CHI::Driver',                    'CHI::Driver::Role::HasSubcaches',
-    'CHI::Driver::Role::IsSizeAware', 'CHI::Driver::Role::IsSubcache'
+push @common_params, qw(
+    discard_policy
+    discard_timeout
+    l1_cache
+    max_size
+    max_size_reduction_factor
+    mirror_cache
+    parent_cache
+    subcache_type
+    subcaches
 );
 my %common_params = map { ( $_, 1 ) } @common_params;
 
@@ -83,8 +183,8 @@ sub declare_unsupported_methods {
     my ( $class, @methods ) = @_;
 
     foreach my $method (@methods) {
-        $class->meta->add_method( $method =>
-              sub { croak "method '$method' not supported by '$class'" } );
+        no strict 'refs';
+        *{"$class\::$method"} = sub { croak "method '$method' not supported by '$class'" };
     }
 }
 
@@ -738,7 +838,7 @@ sub _describe_cache_set {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -748,7 +848,7 @@ CHI::Driver - Base class for all CHI drivers
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 DESCRIPTION
 
@@ -775,7 +875,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
