@@ -1,17 +1,15 @@
 package CHI::Driver::Metacache;
-BEGIN {
-  $CHI::Driver::Metacache::VERSION = '0.56';
+{
+  $CHI::Driver::Metacache::VERSION = '0.57';
 }
 use CHI::Constants qw(CHI_Meta_Namespace);
-use Moose;
+use Moo;
 use strict;
 use warnings;
 
-has 'meta_cache'      => ( is => 'ro', lazy_build => 1 );
+has 'meta_cache'      => ( is => 'lazy', clearer => 'clear_meta_cache', predicate => 'has_meta_cache');
 has 'owner_cache'     => ( is => 'ro', weak_ref => 1 );
-has 'owner_namespace' => ( is => 'ro', lazy_build => 1 );
-
-__PACKAGE__->meta->make_immutable;
+has 'owner_namespace' => ( is => 'lazy', clearer => 'clear_owner_namespace', predicate => 'has_owner_namespace');
 
 sub _build_meta_cache {
     my ($self) = @_;
@@ -56,7 +54,7 @@ sub _prefixed_key {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -66,7 +64,7 @@ CHI::Driver::Metacache - Metacache for internal CHI use
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 SYNOPSIS
 
@@ -89,7 +87,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
