@@ -1,9 +1,9 @@
 package CHI::Driver::Role::Universal;
-BEGIN {
-  $CHI::Driver::Role::Universal::VERSION = '0.56';
+{
+  $CHI::Driver::Role::Universal::VERSION = '0.57';
 }
 use CHI::Constants qw(CHI_Meta_Namespace);
-use Moose::Role;
+use Moo::Role;
 use strict;
 use warnings;
 
