@@ -2,16 +2,14 @@
 # Recommend Data::Serializer for other serializers, rather than reinventing the wheel.
 #
 package CHI::Serializer::Storable;
-BEGIN {
-  $CHI::Serializer::Storable::VERSION = '0.56';
+{
+  $CHI::Serializer::Storable::VERSION = '0.57';
 }
-use Moose;
+use Moo;
 use Storable;
 use strict;
 use warnings;
 
-__PACKAGE__->meta->make_immutable;
-
 sub serialize {
     return Storable::freeze( $_[1] );
 }
