@@ -1,12 +1,12 @@
 # $Id: $
 #
 package CHI::Test;
-BEGIN {
-  $CHI::Test::VERSION = '0.56';
+{
+  $CHI::Test::VERSION = '0.57';
 }
 use Log::Any::Test;    # as early as possible
 use List::MoreUtils qw(uniq);
-use Class::MOP;
+use Module::Runtime qw(require_module);
 use CHI;
 use CHI::Driver::Memory;
 use strict;
@@ -32,7 +32,7 @@ sub export_to_level {
     my ( $class, $level, $ignore ) = @_;
 
     foreach my $package ( $class->packages_to_import() ) {
-        Class::MOP::load_class($package);
+        require_module($package);
         my @export;
         if ( $package eq 'Test::Deep' ) {
 
