@@ -1,13 +1,12 @@
 package CHI::Test::Driver::Writeonly;
-BEGIN {
-  $CHI::Test::Driver::Writeonly::VERSION = '0.56';
+{
+  $CHI::Test::Driver::Writeonly::VERSION = '0.57';
 }
 use Carp;
 use strict;
 use warnings;
-use Moose;
+use Moo;
 extends 'CHI::Driver::Memory';
-__PACKAGE__->meta->make_immutable();
 
 sub fetch {
     my ( $self, $key ) = @_;
